Re: [U-Boot] [PATCH v2 04/12] binman: Rename Entry property to 'section'

2018-06-07 Thread Simon Glass
On 1 June 2018 at 07:38, Simon Glass  wrote:
> Entries are now passed a Section object rather than an Image. Rename this
> property to avoid confusion.
>
> Signed-off-by: Simon Glass 
> ---
>
> Changes in v2: None
>
>  tools/binman/etype/_testing.py|  4 ++--
>  tools/binman/etype/blob.py|  4 ++--
>  tools/binman/etype/entry.py   | 24 +--
>  tools/binman/etype/intel_cmc.py   |  4 ++--
>  tools/binman/etype/intel_descriptor.py|  4 ++--
>  tools/binman/etype/intel_fsp.py   |  4 ++--
>  tools/binman/etype/intel_me.py|  4 ++--
>  tools/binman/etype/intel_mrc.py   |  4 ++--
>  tools/binman/etype/intel_vbt.py   |  4 ++--
>  tools/binman/etype/intel_vga.py   |  4 ++--
>  tools/binman/etype/u_boot.py  |  4 ++--
>  tools/binman/etype/u_boot_dtb.py  |  4 ++--
>  tools/binman/etype/u_boot_dtb_with_ucode.py   | 12 ++
>  tools/binman/etype/u_boot_img.py  |  4 ++--
>  tools/binman/etype/u_boot_nodtb.py|  4 ++--
>  tools/binman/etype/u_boot_spl.py  |  4 ++--
>  tools/binman/etype/u_boot_spl_bss_pad.py  |  4 ++--
>  tools/binman/etype/u_boot_spl_dtb.py  |  4 ++--
>  tools/binman/etype/u_boot_spl_nodtb.py|  4 ++--
>  .../binman/etype/u_boot_spl_with_ucode_ptr.py |  4 ++--
>  tools/binman/etype/u_boot_ucode.py| 14 +--
>  tools/binman/etype/u_boot_with_ucode_ptr.py   | 20 
>  tools/binman/etype/x86_start16.py |  4 ++--
>  tools/binman/etype/x86_start16_spl.py |  4 ++--
>  tools/binman/ftest.py |  2 +-
>  25 files changed, 77 insertions(+), 75 deletions(-)

Applied to u-boot-dm
___
U-Boot mailing list
U-Boot@lists.denx.de
https://lists.denx.de/listinfo/u-boot


[U-Boot] [PATCH v2 04/12] binman: Rename Entry property to 'section'

2018-06-01 Thread Simon Glass
Entries are now passed a Section object rather than an Image. Rename this
property to avoid confusion.

Signed-off-by: Simon Glass 
---

Changes in v2: None

 tools/binman/etype/_testing.py|  4 ++--
 tools/binman/etype/blob.py|  4 ++--
 tools/binman/etype/entry.py   | 24 +--
 tools/binman/etype/intel_cmc.py   |  4 ++--
 tools/binman/etype/intel_descriptor.py|  4 ++--
 tools/binman/etype/intel_fsp.py   |  4 ++--
 tools/binman/etype/intel_me.py|  4 ++--
 tools/binman/etype/intel_mrc.py   |  4 ++--
 tools/binman/etype/intel_vbt.py   |  4 ++--
 tools/binman/etype/intel_vga.py   |  4 ++--
 tools/binman/etype/u_boot.py  |  4 ++--
 tools/binman/etype/u_boot_dtb.py  |  4 ++--
 tools/binman/etype/u_boot_dtb_with_ucode.py   | 12 ++
 tools/binman/etype/u_boot_img.py  |  4 ++--
 tools/binman/etype/u_boot_nodtb.py|  4 ++--
 tools/binman/etype/u_boot_spl.py  |  4 ++--
 tools/binman/etype/u_boot_spl_bss_pad.py  |  4 ++--
 tools/binman/etype/u_boot_spl_dtb.py  |  4 ++--
 tools/binman/etype/u_boot_spl_nodtb.py|  4 ++--
 .../binman/etype/u_boot_spl_with_ucode_ptr.py |  4 ++--
 tools/binman/etype/u_boot_ucode.py| 14 +--
 tools/binman/etype/u_boot_with_ucode_ptr.py   | 20 
 tools/binman/etype/x86_start16.py |  4 ++--
 tools/binman/etype/x86_start16_spl.py |  4 ++--
 tools/binman/ftest.py |  2 +-
 25 files changed, 77 insertions(+), 75 deletions(-)

diff --git a/tools/binman/etype/_testing.py b/tools/binman/etype/_testing.py
index b166a71c4a9..c376dd5c9ca 100644
--- a/tools/binman/etype/_testing.py
+++ b/tools/binman/etype/_testing.py
@@ -10,8 +10,8 @@ import fdt_util
 import tools
 
 class Entry__testing(Entry):
-def __init__(self, image, etype, node):
-Entry.__init__(self, image, etype, node)
+def __init__(self, section, etype, node):
+Entry.__init__(self, section, etype, node)
 
 def ObtainContents(self):
 self.data = 'a'
diff --git a/tools/binman/etype/blob.py b/tools/binman/etype/blob.py
index 10e59e980d6..16b1e5f64d9 100644
--- a/tools/binman/etype/blob.py
+++ b/tools/binman/etype/blob.py
@@ -10,8 +10,8 @@ import fdt_util
 import tools
 
 class Entry_blob(Entry):
-def __init__(self, image, etype, node):
-Entry.__init__(self, image, etype, node)
+def __init__(self, section, etype, node):
+Entry.__init__(self, section, etype, node)
 self._filename = fdt_util.GetString(self._node, "filename", self.etype)
 
 def ObtainContents(self):
diff --git a/tools/binman/etype/entry.py b/tools/binman/etype/entry.py
index 39da7f86022..cbcabe20582 100644
--- a/tools/binman/etype/entry.py
+++ b/tools/binman/etype/entry.py
@@ -19,10 +19,10 @@ import tools
 modules = {}
 
 class Entry(object):
 """An Entry in the image
 
 An entry corresponds to a single node in the device-tree description
-of the image. Each entry ends up being a part of the final image.
+of the section. Each entry ends up being a part of the final section.
 Entries can be placed either right next to each other, or with padding
 between them. The type of the entry determines the data that is in it.
 
@@ -30,9 +30,9 @@ class Entry(object):
 Entry.
 
 Attributes:
-image: The image containing this entry
+section: The section containing this entry
 node: The node that created this entry
-pos: Absolute position of entry within the image, None if not known
+pos: Absolute position of entry within the section, None if not known
 size: Entry size in bytes, None if not known
 contents_size: Size of contents in bytes, 0 by default
 align: Entry start position alignment, or None
@@ -42,8 +42,8 @@ class Entry(object):
 pad_after: Number of pad bytes after the contents, 0 if none
 data: Contents of entry (string of bytes)
 """
-def __init__(self, image, etype, node, read_node=True):
-self.image = image
+def __init__(self, section, etype, node, read_node=True):
+self.section = section
 self.etype = etype
 self._node = node
 self.pos = None
@@ -59,11 +59,11 @@ class Entry(object):
 self.ReadNode()
 
 @staticmethod
-def Create(image, node, etype=None):
+def Create(section, node, etype=None):
 """Create a new entry for a node.
 
 Args:
-image:  Image object containing this node
+section:  Image object containing this node
 node:   Node object containing information about the entry to 
create
 etype:  Entry type to use, or None to work it out (used for tests)
 
@@ -94,7 +94,7 @@ class Entry(object):
 
 # Call its cons
@@ -19,10 +19,10 @@ import tools
 
 class Entry(object):
-"""An Entry in the image
+"""An Entry in the section
 
 An entry corresponds to a single node in the device-tree description